@@ -116,7 +116,7 @@ sub shiftline {
                 next if ($tmp_in_comment);
 
                 open( my $in, $entities{$k} )
-                  or croak wrap_mod( "po4a::xml::shiftline", dgettext( "po4a", "%s: Can't read from %s: %s" ),
+                  or croak wrap_mod( "po4a::xml::shiftline", dgettext( "po4a", "%s: Cannot read from %s: %s" ),
                     $ref, $entities{$k}, $! );
                 while ( defined( my $textline = <$in> ) ) {
                     $linenum++;
@@ -124,7 +124,8 @@ sub shiftline {
                     push @textentries, ( $textline, $textref );
                 }
                 close $in
-                  or croak wrap_mod( "po4a::xml::shiftline", dgettext( "po4a", "%s: Can't close %s after reading: %s" ),
+                  or
+                  croak wrap_mod( "po4a::xml::shiftline", dgettext( "po4a", "%s: Cannot close %s after reading: %s" ),
                     $ref, $entities{$k}, $! );
 
                 push @textentries, ( $after, $ref );
@@ -452,6 +453,7 @@ when it's within another tag (<bbb>).
 
 By default, Processing Instructions (i.e., C<<? ... ?>> tags) are handled as inline tags.
 Pass this option if you want the PI to be handled as breaking tag.
+Note that unprocessed PHP tags are handled as Processing Instructions by the parser.
 
 =item B<nodefault>
 
@@ -632,7 +634,7 @@ sub initialize {
     # by this module or sub-module (unless specified in an option)
     $self->{nodefault} = ();
 
-    print wrap_mod( "po4a::xml::initialize", dgettext( "po4a", "Call treat_options" ) ) if $self->{options}{'debug'};
+    print "Call treat_options\n" if $self->{options}{'debug'};
     $self->treat_options;
 
     #  Clear cache
@@ -1306,7 +1308,7 @@ sub treat_tag {
 
     # Calling this tag type's specific handling (translation of attributes...)
     my $line = &{ $tag_types[$type]->{f_translate} }( $self, @lines );
-    print wrap_mod( "po4a::xml::treat_tag", dgettext( "po4a", "%s: type=%s <%s%s%s%s%s>" ),
+    print wrap_mod( "po4a::xml::treat_tag", "%s: type=%s <%s%s%s%s%s>",
         $lines[1], $type, $match1, $space1, $line, $space2, $match2 )
       if $self->{options}{'debug'};
     $self->pushline( "<" . $match1 . $space1 . $line . $space2 . $match2 . ">" );
@@ -1663,7 +1665,7 @@ sub treat_content {
             # if tag is <!--# ... --> or <!-- ... -->, remove this tag from the
             # input stream and save its content to @comments for use by
             # translate_paragraph.
-            print wrap_mod( "po4a::xml::treat_content", dgettext( "po4a", "%s: type='%s'" ), $paragraph[1], $type )
+            print wrap_mod( "po4a::xml::treat_content", "%s: type='%s'", $paragraph[1], $type )
               if $self->{options}{'debug'};
             ( $eof, @text ) = $self->extract_tag( $type, 1 );
 
@@ -1965,7 +1967,7 @@ sub translate_paragraph {
             # This tag should be translated
             print wrap_mod(
                 "po4a::xml::translate_paragraph",
-                dgettext( "po4a", "%s: path='%s', translation option='%s'" ),
+                "%s: path='%s', translation option='%s'",
                 $paragraph[1], $self->get_path, $translate
             ) if $self->{options}{'debug'};
             $self->pushline(
@@ -1984,7 +1986,7 @@ sub translate_paragraph {
             # Inform that this tag isn't translated in debug mode
             print wrap_mod(
                 "po4a::xml::translate_paragraph",
-                dgettext( "po4a", "%s: path='%s', translation option='%s' (no translation)" ),
+                "%s: path='%s', translation option='%s' (no translation)",
                 $paragraph[1], $self->get_path, $translate
             ) if $self->{options}{'debug'};
             $self->pushline( $self->recode_skipped_text($para) );
@@ -2255,7 +2257,7 @@ sub treat_options {
                     }
                 }
                 print "\n";
-                print wrap_mod( "po4a::xml::treat_options", dgettext( "po4a", "%s: translation option='%s' (valid)" ),
+                print wrap_mod( "po4a::xml::treat_options", "%s: translation option='%s' (valid)",
                     $tag, $self->get_translate_options($tag) );
             }
         }
@@ -2324,6 +2326,11 @@ This removes the returned stream from the input
 
 This ensures that the searched text is outside any quotes
 
+=item B<regex>
+
+This denotes that the first argument is a regular expression rather than
+an plain string
+
 =back
 
 =cut
